@@ -27,6 +27,7 @@
 <script>
 	const view = {
 		refresh_url: null,
+		refresh_simple_url: null,
 		refresh_interval: null,
 		filter_defaults: null,
 		filter: null,
@@ -34,18 +35,27 @@
 		active_filter: null,
 		refresh_timer: null,
 		filter_counter_fetch: null,
+		running: false,
+		timeout: null,
+		deferred: null,
 
-		init({filter_options, refresh_interval, filter_defaults}) {
+		init({filter_options, refresh_url, refresh_interval, filter_defaults}) {
+			this.refresh_url = new Curl(refresh_url, false);
 			this.refresh_interval = refresh_interval;
 			this.filter_defaults = filter_defaults;
 
 			const url = new Curl('zabbix.php', false);
 			url.setArgument('action', 'problem.view.refresh');
-			this.refresh_url = url.getUrl();
+			this.refresh_simple_url = url.getUrl();
 
 			this.initFilter(filter_options);
 			this.initAcknowledge();
 
+			if (this.refresh_interval != 0) {
+				this.running = true;
+				this.scheduleRefresh();
+			}
+
 			$(document).on({
 				mouseenter: function() {
 					if ($(this)[0].scrollWidth > $(this)[0].offsetWidth) {
@@ -108,7 +118,7 @@
 				this.filter_counter_fetch = new AbortController();
 				const filter_item = this.filter._active_item;
 
-				fetch(this.refresh_url, {
+				fetch(this.refresh_simple_url, {
 					method: 'POST',
 					signal: this.filter_counter_fetch.signal,
 					body: new URLSearchParams({filter_counters: 1, counter_index: filter_item._index})
@@ -127,6 +137,9 @@
 					this.global_timerange.from = data.from;
 					this.global_timerange.to = data.to;
 				}
+
+				this.refresh_url.setArgument('page', 1);
+				this.refreshResults();
 			});
 		},
 
@@ -138,7 +151,7 @@
 					chkbxRange.clearSelectedOnFilterChange();
 				}
 
-				window.flickerfreeScreen.refresh('problem');
+				view.refreshNow();
 
 				clearMessages();
 				addMessage(makeMessageBox('good', [], response.message));
@@ -151,14 +164,119 @@
 			});
 		},
 
+		getCurrentResultsTable() {
+			return document.getElementById('flickerfreescreen_problem');
+		},
+
+		getCurrentDebugBlock() {
+			return document.querySelector('.wrapper > .debug-output');
+		},
+
+		setLoading() {
+			this.getCurrentResultsTable().classList.add('is-loading', 'is-loading-fadein', 'delayed-15s');
+		},
+
+		clearLoading() {
+			this.getCurrentResultsTable().classList.remove('is-loading', 'is-loading-fadein', 'delayed-15s');
+		},
+
+		refreshBody(body) {
+			this.getCurrentResultsTable().replaceWith(
+				new DOMParser().parseFromString(body, 'text/html').body.firstElementChild
+			);
+			chkbxRange.init();
+		},
+
+		refreshDebug(debug) {
+			this.getCurrentDebugBlock().replaceWith(
+				new DOMParser().parseFromString(debug, 'text/html').body.firstElementChild
+			);
+		},
+
+		refresh() {
+			this.setLoading();
+
+			const params = this.refresh_url.getArgumentsObject();
+			const exclude = ['action', 'filter_src', 'filter_show_counter', 'filter_custom_time', 'filter_name'];
+			const post_data = Object.keys(params)
+				.filter(key => !exclude.includes(key))
+				.reduce((post_data, key) => {
+					post_data[key] = (typeof params[key] === 'object')
+						? [...params[key]].filter(i => i)
+						: params[key];
+					return post_data;
+				}, {});
+
+			this.deferred = $.ajax({
+				url: this.refresh_simple_url,
+				data: post_data,
+				type: 'post',
+				dataType: 'json'
+			});
+
+			return this.bindDataEvents(this.deferred);
+		},
+
+		refreshNow() {
+			this.unscheduleRefresh();
+			this.refresh();
+		},
+
+		scheduleRefresh() {
+			this.unscheduleRefresh();
+			this.timeout = setTimeout((function () {
+				this.timeout = null;
+				this.refresh();
+			}).bind(this), this.refresh_interval);
+		},
+
+		unscheduleRefresh() {
+			if (this.timeout !== null) {
+				clearTimeout(this.timeout);
+				this.timeout = null;
+			}
+		},
+
+		bindDataEvents(deferred) {
+			const that = this;
+
+			deferred
+				.done(function(response) {
+					that.onDataDone.call(that, response);
+				})
+				.always(this.onDataAlways.bind(this));
+
+			return deferred;
+		},
+
+		onDataAlways() {
+			if (this.running) {
+				this.deferred = null;
+				this.scheduleRefresh();
+			}
+		},
+
+		onDataDone(response) {
+			this.clearLoading();
+			this.refreshBody(response.body);
+
+			if ('messages' in response) {
+				clearMessages();
+				addMessage(makeMessageBox('good', [], response.messages, true, false));
+			}
+
+			('debug' in response) && this.refreshDebug(response.debug);
+		},
+
 		/**
-		 * Refresh results table via window.flickerfreeScreen.refresh call.
+		 * Refresh results table.
 		 */
 		refreshResults() {
 			const url = new Curl();
-			const screen = window.flickerfreeScreen.screens['problem'];
-			const data = $.extend(this.filter_defaults, this.global_timerange, url.getArgumentsObject());
+			const refresh_url = new Curl('zabbix.php', false);
+			const data = Object.assign({}, this.filter_defaults, this.global_timerange, url.getArgumentsObject());
 
+			// Modify filter data.
 			data.inventory = data.inventory
 				? data.inventory.filter(inventory => 'value' in inventory && inventory.value !== '')
 				: data.inventory;
@@ -168,26 +286,14 @@
 			data.severities = data.severities
 				? data.severities.filter((value, key) => value == key)
 				: data.severities;
+			data.page = this.refresh_url.getArgument('page') ?? 1;
 
-			// Modify filter data of flickerfreeScreen object with id 'problem'.
-			if (data.page === null) {
-				delete data.page;
+			if (!data.filter_custom_time) {
+				data.from = this.global_timerange.from;
+				data.to = this.global_timerange.to;
 			}
 
-			if (data.filter_custom_time) {
-				screen.timeline.from = data.from;
-				screen.timeline.to = data.to;
-			}
-			else {
-				screen.timeline.from = this.global_timerange.from;
-				screen.timeline.to = this.global_timerange.to;
-			}
-
-			screen.data.filter = data;
-			screen.data.sort = data.sort;
-			screen.data.sortorder = data.sortorder;
-
-			// Close all opened hint boxes otherwise flicker free screen will not refresh it content.
+			// Close all opened hint boxes, otherwise their contents will not be updated after autorefresh.
 			for (let i = overlays_stack.length - 1; i >= 0; i--) {
 				const hintbox = overlays_stack.getById(overlays_stack.stack[i]);
 
@@ -197,13 +303,23 @@
 				}
 			}
 
-			window.flickerfreeScreen.refresh(screen.id);
+			Object.entries(data).forEach(([key, value]) => {
+				if (['filter_show_counter', 'filter_custom_time', 'action'].indexOf(key) !== -1) {
+					return;
+				}
+
+				refresh_url.setArgument(key, value);
+			});
+
+			refresh_url.setArgument('action', 'problem.view.refresh');
+			this.refresh_url = refresh_url;
+			this.refreshNow();
 		},
 
 		refreshCounters() {
 			clearTimeout(this.refresh_timer);
 
-			fetch(this.refresh_url, {
+			fetch(this.refresh_simple_url, {
 				method: 'POST',
 				body: new URLSearchParams({filter_counters: 1})
 			})
