@@ -240,6 +240,7 @@ final class CItemData {
 			'vmware.datastore.alarms.get[<url>,<uuid>]',
 			'vmware.datastore.discovery[<url>]',
 			'vmware.datastore.hv.list[<url>,<datastore>]',
+			'vmware.datastore.perfcounter[<url>,<uuid>,<path>,<instance>]',
 			'vmware.datastore.property[<url>,<uuid>,<prop>]',
 			'vmware.datastore.read[<url>,<datastore>,<mode>]',
 			'vmware.datastore.size[<url>,<datastore>,<mode>]',
@@ -266,6 +267,7 @@ final class CItemData {
 			'vmware.hv.datastore.size[<url>,<uuid>,<datastore>,<mode>]',
 			'vmware.hv.datastore.write[<url>,<uuid>,<datastore>,<mode>]',
 			'vmware.hv.discovery[<url>]',
+			'vmware.hv.diskinfo.get[<url>,<uuid>]',
 			'vmware.hv.fullname[<url>,<uuid>]',
 			'vmware.hv.hw.cpu.freq[<url>,<uuid>]',
 			'vmware.hv.hw.cpu.model[<url>,<uuid>]',
@@ -397,6 +399,36 @@ final class CItemData {
 		]
 	];
 
+	/**
+	 * Generates an array used to generate item type lookups in the form: item_type => [key_names].
+	 *
+	 * @return array
+	 */
+	public static function getKeysByItemType(): array {
+		$keys_by_type = self::KEYS_BY_TYPE;
+		$keys_by_type_shortened = [];
+
+		foreach ($keys_by_type as $item_type => $available_keys) {
+			$available_keys_shortened = [];
+
+			foreach ($available_keys as $key) {
+				$param_start_pos = strpos($key, '[');
+
+				if ($param_start_pos !== false) {
+					$key = substr($key, 0, $param_start_pos);
+				}
+
+				if (!array_key_exists($key, $available_keys_shortened)) {
+					$available_keys_shortened[] = $key;
+				}
+			}
+
+			$keys_by_type_shortened[$item_type] = $available_keys_shortened;
+		}
+
+		return $keys_by_type_shortened;
+	}
+
 	/**
 	 * Returns items available for the given item type as an array of key => details.
 	 *
@@ -409,12 +441,12 @@ final class CItemData {
 	}
 
 	/**
-	 * Generate an array used for item type lookups in the form: key_name => value_type.
+	 * Generates an array used to generate item type of information lookups in the form: key_name => value_type.
 	 * Value type set to null if key return type varies based on parameters.
 	 *
 	 * @return array
 	 */
-	public static function getTypeSuggestionsByKey(): array {
+	public static function getValueTypeByKey(): array {
 		$type_suggestions = [];
 		$keys = self::get();
 
@@ -1284,6 +1316,10 @@ final class CItemData {
 				'description' => _('VMware datastore hypervisors list, <url> - VMware service URL, <datastore> - datastore name'),
 				'value_type' => ITEM_VALUE_TYPE_TEXT
 			],
+			'vmware.datastore.perfcounter[<url>,<uuid>,<path>,<instance>]' => [
+				'description' => _('VMware datastore performance counter, <url> - VMware service URL, <id> - VMware datastore uuid, <path> - performance counter path, <instance> - performance counter instance'),
+				'value_type' => ITEM_VALUE_TYPE_FLOAT
+			],
 			'vmware.datastore.property[<url>,<uuid>,<prop>]' => [
 				'description' => _('VMware datastore property, <url> - VMware service URL, <uuid> - datastore name, <prop> - property path'),
 				'value_type' => ITEM_VALUE_TYPE_TEXT
@@ -1388,6 +1424,10 @@ final class CItemData {
 				'description' => _('Discovery of VMware hypervisors, <url> - VMware service URL. Returns JSON'),
 				'value_type' => ITEM_VALUE_TYPE_TEXT
 			],
+			'vmware.hv.diskinfo.get[<url>,<uuid>]' => [
+				'description' => _('Info about internal disks of hypervisor required for vmware.datastore.perfcounter, <url> - VMware service URL, <uuid> - VMware hypervisor host name. Returns JSON'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'vmware.hv.fullname[<url>,<uuid>]' => [
 				'description' => _('VMware hypervisor name, <url> - VMware service URL, <uuid> - VMware hypervisor host name'),
 				'value_type' => ITEM_VALUE_TYPE_STR
@@ -1462,7 +1502,7 @@ final class CItemData {
 			],
 			'vmware.hv.perfcounter[<url>,<uuid>,<path>,<instance>]' => [
 				'description' => _('VMware hypervisor performance counter, <url> - VMware service URL, <uuid> - VMware hypervisor host name, <path> - performance counter path, <instance> - performance counter instance'),
-				'value_type' => null
+				'value_type' => ITEM_VALUE_TYPE_FLOAT
 			],
 			'vmware.hv.power[<url>,<uuid>,<max>]' => [
 				'description' => _('Power usage , <url> - VMware service URL, <uuid> - VMware hypervisor host name, <max> - Maximum allowed power usage'),
@@ -1634,7 +1674,7 @@ final class CItemData {
 			],
 			'vmware.vm.perfcounter[<url>,<uuid>,<path>,<instance>]' => [
 				'description' => _('VMware virtual machine performance counter, <url> - VMware service URL, <uuid> - VMware virtual machine host name, <path> - performance counter path, <instance> - performance counter instance'),
-				'value_type' => null
+				'value_type' => ITEM_VALUE_TYPE_FLOAT
 			],
 			'vmware.vm.powerstate[<url>,<uuid>]' => [
 				'description' => _('VMware virtual machine power state, <url> - VMware service URL, <uuid> - VMware virtual machine host name'),
