@@ -41,7 +41,7 @@ function getLocales(): array {
 		'fi_FI' => ['name' => _('Finnish (fi_FI)'),	'display' => false],
 		'fr_FR' => ['name' => _('French (fr_FR)'),	'display' => true],
 		'ka_GE' => ['name' => _('Georgian (ka_GE)'),	'display' => false],
-		'de_DE' => ['name' => _('German (de_DE)'),	'display' => false],
+		'de_DE' => ['name' => _('German (de_DE)'),	'display' => true],
 		'el_GR' => ['name' => _('Greek (el_GR)'),	'display' => false],
 		'he_IL' => ['name' => _('Hebrew (he_IL)'),	'display' => true],
 		'hu_HU' => ['name' => _('Hungarian (hu_HU)'),	'display' => false],
@@ -63,7 +63,7 @@ function getLocales(): array {
 		'sv_SE' => ['name' => _('Swedish (sv_SE)'),	'display' => false],
 		'tr_TR' => ['name' => _('Turkish (tr_TR)'),	'display' => true],
 		'uk_UA' => ['name' => _('Ukrainian (uk_UA)'),	'display' => true],
-		'vi_VN' => ['name' => _('Vietnamese (vi_VN)'),	'display' => false]
+		'vi_VN' => ['name' => _('Vietnamese (vi_VN)'),	'display' => true]
 	];
 }
 
