@@ -27,6 +27,9 @@ setupLocale(array_key_exists('lang', $_GET) ? (string) $_GET['lang'] : 'en_GB');
 
 require_once dirname(__FILE__).'/include/js.inc.php';
 
+require_once dirname(__FILE__).'/include/defines.inc.php';
+require_once dirname(__FILE__).'/include/classes/helpers/CCookieHelper.php';
+
 // available scripts 'scriptFileName' => 'path relative to js/'
 $available_js = [
 	'common.js' => '',
@@ -220,7 +223,7 @@ $translate_strings = [
 		'Execute' => _('Execute'),
 		'Execution confirmation' => _('Execution confirmation'),
 		'S_YEAR_SHORT' => _x('y', 'year short'),
-		'S_MONTH_SHORT' => _x('m', 'month short'),
+		'S_MONTH_SHORT' => _x('M', 'month short'),
 		'S_DAY_SHORT' => _x('d', 'day short'),
 		'S_HOUR_SHORT' => _x('h', 'hour short'),
 		'S_MINUTE_SHORT' => _x('m', 'minute short'),
@@ -296,7 +299,8 @@ $translate_strings = [
 		'S_CANNOT_SUPPORT_NOTIFICATION_AUDIO' => _('Cannot support notification audio for this device.'),
 		'S_UNMUTE' => _('Unmute'),
 		'S_CLOSE' => _('Close'),
-		'S_SNOOZE' => _('Snooze')
+		'S_SNOOZE' => _('Snooze'),
+		'Unexpected server error.' => _('Unexpected server error.')
 	],
 	'class.cookie.js' => [
 		'S_MAX_COOKIE_SIZE_REACHED' => _('We are sorry, the maximum possible number of elements to remember has been reached.')
@@ -323,7 +327,8 @@ $translate_strings = [
 	],
 	'hostmacrosmanager.js' => [
 		'Change' => _x('Change', 'verb'),
-		'Remove' => _('Remove')
+		'Remove' => _('Remove'),
+		'Revert' => _('Revert')
 	],
 	'multilineinput.js' => [
 		'S_N_CHAR_COUNT' => _('%1$s characters'),
@@ -362,6 +367,7 @@ $translate_strings = [
 		'Delete' => _('Delete'),
 		'Delete dashboard?' => _('Delete dashboard?'),
 		'Do you wish to replace the conditional expression?' => _('Do you wish to replace the conditional expression?'),
+		'Execute now' => _('Execute now'),
 		'Item' => _('Item'),
 		'Insert expression' => _('Insert expression'),
 		'Sharing' => _('Sharing'),
@@ -415,7 +421,6 @@ $translate_strings = [
 	],
 	'macrovalue.js' => [
 		'Set new value' => _('Set new value'),
-		'path/to/secret:key' => _('path/to/secret:key'),
 		'value' => _('value')
 	],
 	'popup.condition.common.js' => [
@@ -462,9 +467,6 @@ if (empty($_GET['files'])) {
 		'init.js'
 	];
 
-	require_once dirname(__FILE__).'/include/defines.inc.php';
-	require_once dirname(__FILE__).'/include/classes/helpers/CCookieHelper.php';
-
 	if (CCookieHelper::has(ZBX_SESSION_NAME)) {
 		$session = json_decode(base64_decode(CCookieHelper::get(ZBX_SESSION_NAME)), true);
 		$js .= 'window.ZBX_SESSION_NAME = "'.crc32($session['sessionid']).'";';
